Re-exports
pub use export_plugin_impl as export_plugin;
Modules
- ffi
- FFI helpers for WASM plugins
Macros
- export_
build - Macro to export build function with proper FFI wrapper
- export_
migrate - Macro to export migrate function with proper FFI wrapper
- export_
schema - Macro to export schema function with proper FFI wrapper
- export_
validate_ config - Macro to export validate_config function with proper FFI wrapper
- schema_
from_ file - Helper macro to embed a schema.cdm file and export it via the WASM
_schema()function.
Structs
- Field
Definition - Model
Definition - Output
File - Output file from build or migrate
- Path
Segment - Path segment for error reporting
- Schema
- Schema types
- Type
Alias Definition - Utils
- Utility functions provided by CDM runtime
- Validation
Error - Validation error with structured path
Enums
- Case
Format - Case format for string conversion
- Config
Level - Configuration level for validation
- Delta
- Delta types for migrations
- Severity
- Error severity
- Type
Expression - Value
Functions
- export_
plugin_ impl - Placeholder for the actual proc macro In a real implementation, this would be in a separate proc-macro crate