Module ffi

Module ffi 

FFI helpers for WASM plugins

This module provides utilities for plugin authors to implement the WASM FFI layer without having to deal with raw pointers and memory management.

Functions

_alloc
Standard WASM memory allocation function
_dealloc
Standard WASM memory deallocation function
ffi_build
Helper for implementing _build WASM export
ffi_migrate
Helper for implementing _migrate WASM export
ffi_schema
Helper for implementing _schema WASM export
ffi_validate_config
Helper for implementing _validate_config WASM export